# CausalRec - a python package for ... 
# Note: 
This is the first draft to keep the name of the package for upcoming projects


An implementation to use Causal models to  .....
This paper can be found at: .......

# Infrastructure used to run experiments:
* OS: Windows, Linux, Ubuntu.
* CPU: 12th Gen Intel(R) Core(TM) i7-1255U   1.70 GHz.
* RAM: 16 GB.

